##  Steps to Create Integration
Steps | Notes
---|---
Review Swagger API documentation |
Schemas should contain the uploaded data, split into Points | Each Point has a unique time stamp
Charts describe how to represent the Schema graphically | For example as a Bar Chart
Charts contain Rules which define how the measurement data is mapped to your Fact Sheets (one option is to map using the External ID) |


YesNo
Send
